==> rds-1.93.0-sources.jar: software/amazon/awscdk/services/rds/Credentials.java <==
package software.amazon.awscdk.services.rds;

/**
 * Username and password combination.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:51.507Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.rds.$Module.class, fqn = "@aws-cdk/aws-rds.Credentials")
public abstract class Credentials extends software.amazon.jsii.JsiiObject {

    protected Credentials(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Credentials(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected Credentials() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Creates Credentials with a password generated and stored in Secrets Manager.
     * <p>
     * @param username This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.Credentials fromGeneratedSecret(final @org.jetbrains.annotations.NotNull java.lang.String username, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.rds.CredentialsBaseOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.Credentials.class, "fromGeneratedSecret", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.Credentials.class), new Object[] { java.util.Objects.requireNonNull(username, "username is required"), options });
    }

    /**
     * Creates Credentials with a password generated and stored in Secrets Manager.
     * <p>
     * @param username This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.Credentials fromGeneratedSecret(final @org.jetbrains.annotations.NotNull java.lang.String username) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.Credentials.class, "fromGeneratedSecret", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.Credentials.class), new Object[] { java.util.Objects.requireNonNull(username, "username is required") });
    }

    /**
     * Creates Credentials from a password.
     * <p>
     * Do not put passwords in your CDK code directly.
     * <p>
     * @param username This parameter is required.
     * @param password This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.Credentials fromPassword(final @org.jetbrains.annotations.NotNull java.lang.String username, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.SecretValue password) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.Credentials.class, "fromPassword", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.Credentials.class), new Object[] { java.util.Objects.requireNonNull(username, "username is required"), java.util.Objects.requireNonNull(password, "password is required") });
    }

    /**
     * Creates Credentials from an existing Secrets Manager ``Secret`` (or ``DatabaseSecret``).
     * <p>
     * The Secret must be a JSON string with a <code>username</code> and <code>password</code> field:
     * <p>
     * <blockquote><pre>
     * {
     *    ...
     *    "username": &lt;required: username&gt;,
     *    "password": &lt;required: password&gt;,
     * }
     * </pre></blockquote>
     * <p>
     * @param secret The secret where the credentials are stored. This parameter is required.
     * @param username The username defined in the secret.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.Credentials fromSecret(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.secretsmanager.ISecret secret, final @org.jetbrains.annotations.Nullable java.lang.String username) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.Credentials.class, "fromSecret", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.Credentials.class), new Object[] { java.util.Objects.requireNonNull(secret, "secret is required"), username });
    }

    /**
     * Creates Credentials from an existing Secrets Manager ``Secret`` (or ``DatabaseSecret``).
     * <p>
     * The Secret must be a JSON string with a <code>username</code> and <code>password</code> field:
     * <p>
     * <blockquote><pre>
     * {
     *    ...
     *    "username": &lt;required: username&gt;,
     *    "password": &lt;required: password&gt;,
     * }
     * </pre></blockquote>
     * <p>
     * @param secret The secret where the credentials are stored. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.Credentials fromSecret(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.secretsmanager.ISecret secret) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.Credentials.class, "fromSecret", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.Credentials.class), new Object[] { java.util.Objects.requireNonNull(secret, "secret is required") });
    }

    /**
     * (deprecated) Creates Credentials for the given username, and optional password and key.
     * <p>
     * If no password is provided, one will be generated and stored in Secrets Manager.
     * <p>
     * @deprecated use `fromGeneratedSecret()` or `fromPassword()` for new Clusters and Instances.
     * Note that switching from `fromUsername()` to `fromGeneratedSecret()` or `fromPassword()` for already deployed
     * Clusters or Instances will result in their replacement!
     * @param username This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.Credentials fromUsername(final @org.jetbrains.annotations.NotNull java.lang.String username, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.rds.CredentialsFromUsernameOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.Credentials.class, "fromUsername", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.Credentials.class), new Object[] { java.util.Objects.requireNonNull(username, "username is required"), options });
    }

    /**
     * (deprecated) Creates Credentials for the given username, and optional password and key.
     * <p>
     * If no password is provided, one will be generated and stored in Secrets Manager.
     * <p>
     * @deprecated use `fromGeneratedSecret()` or `fromPassword()` for new Clusters and Instances.
     * Note that switching from `fromUsername()` to `fromGeneratedSecret()` or `fromPassword()` for already deployed
     * Clusters or Instances will result in their replacement!
     * @param username This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.Credentials fromUsername(final @org.jetbrains.annotations.NotNull java.lang.String username) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.Credentials.class, "fromUsername", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.Credentials.class), new Object[] { java.util.Objects.requireNonNull(username, "username is required") });
    }

    /**
     * Username.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.NotNull java.lang.String getUsername();

    /**
     * KMS encryption key to encrypt the generated secret.
     * <p>
     * Default: - default master key
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.kms.IKey getEncryptionKey();

    /**
     * The characters to exclude from the generated password.
     * <p>
     * Only used if {&#64;link password} has not been set.
     * <p>
     * Default: - the DatabaseSecret default exclude character set (" %+~`#$&*()|[]{}:;<>?!'/
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.Nullable java.lang.String getExcludeCharacters();

    /**
     * Password.
     * <p>
     * Do not put passwords in your CDK code directly.
     * <p>
     * Default: - a Secrets Manager generated password
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.SecretValue getPassword();

    /**
     * Secret used to instantiate this Login.
     * <p>
     * Default: - none
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.secretsmanager.ISecret getSecret();

    /**
     * Whether the username should be referenced as a string and not as a dynamic reference to the username in the secret.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.Nullable java.lang.Boolean getUsernameAsString();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    private static final class Jsii$Proxy extends software.amazon.awscdk.services.rds.Credentials {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Username.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.NotNull java.lang.String getUsername() {
            return software.amazon.jsii.Kernel.get(this, "username", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * KMS encryption key to encrypt the generated secret.
         * <p>
         * Default: - default master key
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.kms.IKey getEncryptionKey() {
            return software.amazon.jsii.Kernel.get(this, "encryptionKey", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.kms.IKey.class));
        }

        /**
         * The characters to exclude from the generated password.
         * <p>
         * Only used if {&#64;link password} has not been set.
         * <p>
         * Default: - the DatabaseSecret default exclude character set (" %+~`#$&*()|[]{}:;<>?!'/
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.Nullable java.lang.String getExcludeCharacters() {
            return software.amazon.jsii.Kernel.get(this, "excludeCharacters", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Password.
         * <p>
         * Do not put passwords in your CDK code directly.
         * <p>
         * Default: - a Secrets Manager generated password
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.SecretValue getPassword() {
            return software.amazon.jsii.Kernel.get(this, "password", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.SecretValue.class));
        }

        /**
         * Secret used to instantiate this Login.
         * <p>
         * Default: - none
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.secretsmanager.ISecret getSecret() {
            return software.amazon.jsii.Kernel.get(this, "secret", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.ISecret.class));
        }

        /**
         * Whether the username should be referenced as a string and not as a dynamic reference to the username in the secret.
         * <p>
         * Default: false
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.Nullable java.lang.Boolean getUsernameAsString() {
            return software.amazon.jsii.Kernel.get(this, "usernameAsString", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }
    }
}

==> rds-1.100.0-sources.jar: software/amazon/awscdk/services/rds/Credentials.java <==
package software.amazon.awscdk.services.rds;

/**
 * Username and password combination.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:21.724Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.rds.$Module.class, fqn = "@aws-cdk/aws-rds.Credentials")
public abstract class Credentials extends software.amazon.jsii.JsiiObject {

    protected Credentials(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Credentials(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected Credentials() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Creates Credentials with a password generated and stored in Secrets Manager.
     * <p>
     * @param username This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.Credentials fromGeneratedSecret(final @org.jetbrains.annotations.NotNull java.lang.String username, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.rds.CredentialsBaseOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.Credentials.class, "fromGeneratedSecret", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.Credentials.class), new Object[] { java.util.Objects.requireNonNull(username, "username is required"), options });
    }

    /**
     * Creates Credentials with a password generated and stored in Secrets Manager.
     * <p>
     * @param username This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.Credentials fromGeneratedSecret(final @org.jetbrains.annotations.NotNull java.lang.String username) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.Credentials.class, "fromGeneratedSecret", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.Credentials.class), new Object[] { java.util.Objects.requireNonNull(username, "username is required") });
    }

    /**
     * Creates Credentials from a password.
     * <p>
     * Do not put passwords in your CDK code directly.
     * <p>
     * @param username This parameter is required.
     * @param password This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.Credentials fromPassword(final @org.jetbrains.annotations.NotNull java.lang.String username, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.SecretValue password) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.Credentials.class, "fromPassword", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.Credentials.class), new Object[] { java.util.Objects.requireNonNull(username, "username is required"), java.util.Objects.requireNonNull(password, "password is required") });
    }

    /**
     * Creates Credentials from an existing Secrets Manager ``Secret`` (or ``DatabaseSecret``).
     * <p>
     * The Secret must be a JSON string with a <code>username</code> and <code>password</code> field:
     * <p>
     * <blockquote><pre>
     * {
     *    ...
     *    "username": &lt;required: username&gt;,
     *    "password": &lt;required: password&gt;,
     * }
     * </pre></blockquote>
     * <p>
     * @param secret The secret where the credentials are stored. This parameter is required.
     * @param username The username defined in the secret.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.Credentials fromSecret(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.secretsmanager.ISecret secret, final @org.jetbrains.annotations.Nullable java.lang.String username) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.Credentials.class, "fromSecret", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.Credentials.class), new Object[] { java.util.Objects.requireNonNull(secret, "secret is required"), username });
    }

    /**
     * Creates Credentials from an existing Secrets Manager ``Secret`` (or ``DatabaseSecret``).
     * <p>
     * The Secret must be a JSON string with a <code>username</code> and <code>password</code> field:
     * <p>
     * <blockquote><pre>
     * {
     *    ...
     *    "username": &lt;required: username&gt;,
     *    "password": &lt;required: password&gt;,
     * }
     * </pre></blockquote>
     * <p>
     * @param secret The secret where the credentials are stored. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.Credentials fromSecret(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.secretsmanager.ISecret secret) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.Credentials.class, "fromSecret", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.Credentials.class), new Object[] { java.util.Objects.requireNonNull(secret, "secret is required") });
    }

    /**
     * (deprecated) Creates Credentials for the given username, and optional password and key.
     * <p>
     * If no password is provided, one will be generated and stored in Secrets Manager.
     * <p>
     * @deprecated use `fromGeneratedSecret()` or `fromPassword()` for new Clusters and Instances.
     * Note that switching from `fromUsername()` to `fromGeneratedSecret()` or `fromPassword()` for already deployed
     * Clusters or Instances will result in their replacement!
     * @param username This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.Credentials fromUsername(final @org.jetbrains.annotations.NotNull java.lang.String username, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.rds.CredentialsFromUsernameOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.Credentials.class, "fromUsername", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.Credentials.class), new Object[] { java.util.Objects.requireNonNull(username, "username is required"), options });
    }

    /**
     * (deprecated) Creates Credentials for the given username, and optional password and key.
     * <p>
     * If no password is provided, one will be generated and stored in Secrets Manager.
     * <p>
     * @deprecated use `fromGeneratedSecret()` or `fromPassword()` for new Clusters and Instances.
     * Note that switching from `fromUsername()` to `fromGeneratedSecret()` or `fromPassword()` for already deployed
     * Clusters or Instances will result in their replacement!
     * @param username This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.Credentials fromUsername(final @org.jetbrains.annotations.NotNull java.lang.String username) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.Credentials.class, "fromUsername", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.Credentials.class), new Object[] { java.util.Objects.requireNonNull(username, "username is required") });
    }

    /**
     * Username.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.NotNull java.lang.String getUsername();

    /**
     * KMS encryption key to encrypt the generated secret.
     * <p>
     * Default: - default master key
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.kms.IKey getEncryptionKey();

    /**
     * The characters to exclude from the generated password.
     * <p>
     * Only used if {&#64;link password} has not been set.
     * <p>
     * Default: - the DatabaseSecret default exclude character set (" %+~`#$&*()|[]{}:;<>?!'/
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.Nullable java.lang.String getExcludeCharacters();

    /**
     * Password.
     * <p>
     * Do not put passwords in your CDK code directly.
     * <p>
     * Default: - a Secrets Manager generated password
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.SecretValue getPassword();

    /**
     * Secret used to instantiate this Login.
     * <p>
     * Default: - none
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.secretsmanager.ISecret getSecret();

    /**
     * The name to use for the Secret if a new Secret is to be generated in SecretsManager for these Credentials.
     * <p>
     * Default: - A name is generated by CloudFormation.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.Nullable java.lang.String getSecretName();

    /**
     * Whether the username should be referenced as a string and not as a dynamic reference to the username in the secret.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.Nullable java.lang.Boolean getUsernameAsString();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    private static final class Jsii$Proxy extends software.amazon.awscdk.services.rds.Credentials {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Username.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.NotNull java.lang.String getUsername() {
            return software.amazon.jsii.Kernel.get(this, "username", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * KMS encryption key to encrypt the generated secret.
         * <p>
         * Default: - default master key
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.kms.IKey getEncryptionKey() {
            return software.amazon.jsii.Kernel.get(this, "encryptionKey", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.kms.IKey.class));
        }

        /**
         * The characters to exclude from the generated password.
         * <p>
         * Only used if {&#64;link password} has not been set.
         * <p>
         * Default: - the DatabaseSecret default exclude character set (" %+~`#$&*()|[]{}:;<>?!'/
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.Nullable java.lang.String getExcludeCharacters() {
            return software.amazon.jsii.Kernel.get(this, "excludeCharacters", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Password.
         * <p>
         * Do not put passwords in your CDK code directly.
         * <p>
         * Default: - a Secrets Manager generated password
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.SecretValue getPassword() {
            return software.amazon.jsii.Kernel.get(this, "password", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.SecretValue.class));
        }

        /**
         * Secret used to instantiate this Login.
         * <p>
         * Default: - none
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.secretsmanager.ISecret getSecret() {
            return software.amazon.jsii.Kernel.get(this, "secret", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.ISecret.class));
        }

        /**
         * The name to use for the Secret if a new Secret is to be generated in SecretsManager for these Credentials.
         * <p>
         * Default: - A name is generated by CloudFormation.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.Nullable java.lang.String getSecretName() {
            return software.amazon.jsii.Kernel.get(this, "secretName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Whether the username should be referenced as a string and not as a dynamic reference to the username in the secret.
         * <p>
         * Default: false
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.Nullable java.lang.Boolean getUsernameAsString() {
            return software.amazon.jsii.Kernel.get(this, "usernameAsString", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }
    }
}
